@@ -1,14 +1,14 @@
 use std::process;
 
+use clap::Parser;
 use log::{error, LevelFilter};
 use rocfl::cmd::opts::*;
 use rocfl::config::Config;
 use rocfl::ocfl::RocflError;
 use rocfl::{cmd, config};
-use structopt::StructOpt;
 
 fn main() {
-    let mut args = RocflArgs::from_args();
+    let mut args = RocflArgs::parse();
 
     let log_level = if args.quiet {
         LevelFilter::Off
@@ -22,6 +22,7 @@ fn main() {
         .filter_level(log_level)
         .format_timestamp(None)
         .format_module_path(false)
+        .format_target(false)
         .init();
 
     let config = match config::load_config(&args.name) {
