@@ -103,10 +103,6 @@ fn println(value: impl Display) {
     let _ = writeln!(io::stdout(), "{}", value);
 }
 
-fn print(value: impl Display) {
-    let _ = write!(io::stdout(), "{}", value);
-}
-
 fn paint<'b, I, S: 'b + ToOwned + ?Sized>(
     no_styles: bool,
     style: Style,
@@ -138,7 +134,7 @@ pub fn init_repo(cmd: &InitCmd, args: &RocflArgs, config: &Config) -> Result<()>
     } else {
         let _ = OcflRepo::init_fs_repo(
             config.root.as_ref().unwrap(),
-            config.staging_root.as_ref().map(|r| Path::new(r)),
+            config.staging_root.as_ref().map(Path::new),
             create_layout(cmd.layout, cmd.config_file.as_deref())?,
         )?;
     }
@@ -165,7 +161,7 @@ fn create_repo(config: &Config) -> Result<OcflRepo> {
     } else {
         OcflRepo::fs_repo(
             config.root.as_ref().unwrap(),
-            config.staging_root.as_ref().map(|r| Path::new(r)),
+            config.staging_root.as_ref().map(Path::new),
         )
     }
 }
@@ -199,6 +195,10 @@ fn create_layout(layout_name: Layout, config_file: Option<&Path>) -> Result<Opti
             LayoutExtensionName::FlatOmitPrefixLayout,
             config_bytes.as_deref(),
         )?),
+        Layout::NTupleOmitPrefix => Some(StorageLayout::new(
+            LayoutExtensionName::NTupleOmitPrefixLayout,
+            config_bytes.as_deref(),
+        )?),
     };
 
     Ok(layout)
